diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/style/StylePluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/style/StylePluginBase.php
index 76bbb4250bec47762af68d3861532d6370f2c4ff..9235b2ab2a1340716c3c84815501af218c0fa805 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/style/StylePluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/style/StylePluginBase.php
@@ -385,7 +385,7 @@ public function wizardSubmit(&$form, &$form_state, WizardInterface $wizard, &$di
    * interfere with the sorts. If so it should build; if it returns
    * any non-TRUE value, normal sorting will NOT be added to the query.
    */
-  function build_sort() { return TRUE; }
+  public function buildSort() { return TRUE; }
 
   /**
    * Called by the view builder to let the style build a second set of
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/style/Table.php b/core/modules/views/lib/Drupal/views/Plugin/views/style/Table.php
index f6fe7e51792b49bffe1601ef4d13c3ed1a36ac0c..490cdbb62fb68be763124e5a13fc991466ea4edc 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/style/Table.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/style/Table.php
@@ -103,7 +103,7 @@ protected function defineOptions() {
   /**
    * {@inheritdoc}
    */
-  function build_sort() {
+  public function buildSort() {
     $order = $this->request->query->get('order');
     if (!isset($order) && ($this->options['default'] == -1 || empty($this->view->field[$this->options['default']]))) {
       return TRUE;
diff --git a/core/modules/views/lib/Drupal/views/ViewExecutable.php b/core/modules/views/lib/Drupal/views/ViewExecutable.php
index a5ca905a17ec373dc61046878cbce394acfc1dfc..263df0568641d34b178f938da0a9cb49369221a5 100644
--- a/core/modules/views/lib/Drupal/views/ViewExecutable.php
+++ b/core/modules/views/lib/Drupal/views/ViewExecutable.php
@@ -1050,7 +1050,7 @@ public function build($display_id = NULL) {
     // Build our sort criteria if we were instructed to do so.
     if (!empty($this->build_sort)) {
       // Allow the style handler to deal with sorting.
-      if ($this->style_plugin->build_sort()) {
+      if ($this->style_plugin->buildSort()) {
         $this->_build('sort');
       }
       // allow the plugin to build second sorts as well.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/StyleTableUnitTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/StyleTableUnitTest.php
index 38e67b4fe0f5fe74950c836d3c01d4bcf95d6ac8..aa35d364680bee9c6d5115242c4cbf6ac194f6ab 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/StyleTableUnitTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/StyleTableUnitTest.php
@@ -44,7 +44,7 @@ public function testTable() {
     $view->initQuery();
     $style_plugin = $view->style_plugin;
 
     // Test the build_sort() method.
     $request = new Request();
     $this->container->enterScope('request');
     $this->container->set('request', $request);
@@ -52,20 +52,20 @@ public function testTable() {
     $style_plugin->options['override'] = FALSE;
 
     $style_plugin->options['default'] = '';
-    $this->assertTrue($style_plugin->build_sort(), 'If no order and no default order is specified, the normal sort should be used.');
+    $this->assertTrue($style_plugin->buildSort(), 'If no order and no default order is specified, the normal sort should be used.');
 
     $style_plugin->options['default'] = 'id';
-    $this->assertTrue($style_plugin->build_sort(), 'If no order but a default order is specified, the normal sort should be used.');
+    $this->assertTrue($style_plugin->buildSort(), 'If no order but a default order is specified, the normal sort should be used.');
 
     $request->attributes->set('order', $this->randomName());
-    $this->assertTrue($style_plugin->build_sort(), 'If no valid field is chosen for order, the normal sort should be used.');
+    $this->assertTrue($style_plugin->buildSort(), 'If no valid field is chosen for order, the normal sort should be used.');
 
     $request->attributes->set('order', 'id');
-    $this->assertTrue($style_plugin->build_sort(), 'If a valid order is specified but the table is configured to not override, the normal sort should be used.');
+    $this->assertTrue($style_plugin->buildSort(), 'If a valid order is specified but the table is configured to not override, the normal sort should be used.');
 
     $style_plugin->options['override'] = TRUE;
 
-    $this->assertFalse($style_plugin->build_sort(), 'If a valid order is specified and the table is configured to override, the normal sort should not be used.');
+    $this->assertFalse($style_plugin->buildSort(), 'If a valid order is specified and the table is configured to override, the normal sort should not be used.');
 
     // Test the build_sort_post() method.
     $request = new Request();
@@ -44,7 +44,7 @@ public function testTable() {
     $style_plugin = $view->style_plugin;
 
-    // Test the build_sort() method.
+    // Test the buildSort() method.
     $request = new Request();
     $this->container->enterScope('request');